[![Build Status](https://travis-ci.org/raspi/pypdnsrest.svg?branch=master)](https://travis-ci.org/raspi/pypdnsrest)
[![Code Climate](https://codeclimate.com/github/raspi/pypdnsrest/badges/gpa.svg)](https://codeclimate.com/github/raspi/pypdnsrest)
[![Test Coverage](https://codeclimate.com/github/raspi/pypdnsrest/badges/coverage.svg)](https://codeclimate.com/github/raspi/pypdnsrest/coverage)
[![Issue Count](https://codeclimate.com/github/raspi/pypdnsrest/badges/issue_count.svg)](https://codeclimate.com/github/raspi/pypdnsrest)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/26121d282a5746c8a4d4b8468aa55969)](https://www.codacy.com/app/raspi/pypdnsrest?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=raspi/pypdnsrest&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/raspi/pypdnsrest/branch/master/graph/badge.svg)](https://codecov.io/gh/raspi/pypdnsrest)
[![PyPI](https://img.shields.io/pypi/v/pypdnsrest.svg)](https://pypi.python.org/pypi/pypdnsrest/)
[![PyPI](https://img.shields.io/pypi/pyversions/pypdnsrest.svg)]()
[![PyPI](https://img.shields.io/pypi/format/pypdnsrest.svg)]()
[![PyPI](https://img.shields.io/pypi/status/pypdnsrest.svg)]()
[![PyPI](https://img.shields.io/pypi/l/pypdnsrest.svg)]()

PowerDNS HTTP REST API Python client
 
https://doc.powerdns.com/md/httpapi/README/
 
## Requirements
* Python 3.5+
* requests

## Run tests
    python3.5 -m unittest discover -v pypdnsrest/tests/
